<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=ar
// ** ne pas modifier le fichier **

return [

	// I
	'images_description' => 'مرشحات معالجة الصور والألوان ',
	'images_slogan' => 'مرشحات معالجة الصور والألوان',
];
